@@ -166,19 +166,20 @@ func (c *InboundDetourConfig) Build() (*core.InboundHandlerConfig, error) {
 		receiverSettings.Listen = c.ListenOn.Build()
 		listenDS := c.ListenOn.Family().IsDomain() && (c.ListenOn.Domain()[0] == '/' || c.ListenOn.Domain()[0] == '@')
 		listenIP := c.ListenOn.Family().IsIP() || (c.ListenOn.Family().IsDomain() && c.ListenOn.Domain() == "localhost")
-		if listenIP {
+		switch {
+		case listenIP:
 			// Listen on specific IP, must set PortRange
 			if c.PortRange == nil {
 				return nil, newError("Listen on specific ip without port in InboundDetour.")
 			}
 			// Listen on IP:Port
 			receiverSettings.PortRange = c.PortRange.Build()
-		} else if listenDS {
+		case listenDS:
 			if c.PortRange != nil {
 				// Listen on Unix Domain Socket, PortRange should be nil
 				receiverSettings.PortRange = nil
 			}
-		} else {
+		default:
 			return nil, newError("unable to listen on domain address: ", c.ListenOn.Domain())
 		}
 	}
